#!/bin/bash

echo -e "XXXXXXX\t[N+](=O)([O-])[O-].[NH3+][C@H](C1=CC=CC=C1)C(=O)O\tC(=O)([C@@H](c1ccccc1)[NH3+])O.N(=O)(=O)[O-]" \
    | smi_isomorphism
